from setuptools import setup

setup(
    name='hello-world-test-coolegor',
    version='0.1.0',
    description='A example Python "hello world" package',
    author='Egor Kuleshov',
    url='https://github.com/Kuleshovegor',
    author_email='kuleshovegor2001@gmail.com',
    packages=['hello-world-test-coolegor'],
    install_requires=['numpy>=1.19.5'],

    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Science/Research',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
)
